@@ -19,6 +19,23 @@ headers = {
     'rix-api-user': '1',
 }
 
+"https://api.ffire.cc/api/channel/multi_key/manage"
+
+
+async def manage_multi_key(id: int, base_url: str, action: str = "enable_all_keys") -> ChannelInfo:
+    # "disable_all_keys"
+    payload = {
+        "channel_id": id,
+        "action": action
+    }
+    async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=30) as client:
+        response = await client.post("/api/channel/multi_key/manage", json=payload)
+        response.raise_for_status()
+
+        data = response.json()
+        logger.debug(bjson(data))
+        return data
+
 
 async def get_channel_info(id: int, base_url: str) -> ChannelInfo:
     params = {"keyword": id}  # keyword=21222&group=&model=&id_sort=true&tag_mode=false&p=1&page_size=100
@@ -28,7 +45,7 @@ async def get_channel_info(id: int, base_url: str) -> ChannelInfo:
         response.raise_for_status()
 
         data = response.json()
-        # logger.debug(bjson(data))
+        logger.debug(bjson(data))
         if (items := data.get("data", {}).get("items", [])) and (item := items[0]):
             return item['status']  # status==1 是正常
 
@@ -176,7 +193,12 @@ async def create_or_update_channel(
         logger.debug(response.text)
 
         response.raise_for_status()
-        logger.debug(response.json())
+
+        data = response.json()
+        logger.debug(bjson(data))
+        if (data := data.get("data")) and data['channel_info']['is_multi_key']:
+            await manage_multi_key(data['id'], base_url=base_url)
+
         return response.json()
 
 
@@ -268,15 +290,24 @@ if __name__ == '__main__':
     # arun(create_or_update_channel(tokens, base_url))
     # arun(create_or_update_channel(tokens))
     # # arun(delete_channel(range(10000, 20000)))
-    key = "KEY"
-    request = ChannelInfo(name='', key=key)
-    request = ChannelInfo(id=21223, key=key, used_quota=0.001)
+    key = "KEY\nKEY2\nKEY2\nKEY2\nKEY2"
+    # request = ChannelInfo(id = 1, name='xx', key=key)
+    # request = ChannelInfo(id=21223, key=key, used_quota=0.001)
+    request = ChannelInfo(id=29483, key=key, used_quota=0.001,
+                          # key_mode="append"
+                          )
 
-    # arun(create_or_update_channel(request, base_url=base_url))
+
+
+    request = ChannelInfo(id=29494, key=key, type=45)
+
+    arun(create_or_update_channel(request, base_url=base_url))
     #
     # arun(exist_channel(request, base_url=base_url))
 
-    arun(get_channel_info(21222, base_url=base_url))
-    # arun(get_channel_info(21223, base_url=base_url))
+    # arun(get_channel_info(21222, base_url=base_url))
+    # arun(get_channel_info(29483, base_url=base_url))
 
     # arun(delete_channel(range(10015, 10032), base_url=base_url))
+
+    # arun(manage_multi_key(29483, base_url=base_url))
