@@ -8,6 +8,7 @@
 # @Software     : PyCharm
 # @Description  : todo: redis缓存, 通过数据库获取 用户余额，补偿余额【扣费逻辑：用户余额够就直接计费，先请求计费+创建任务】，计费函数可返回用户信息
 import json
+import os
 
 from meutils.pipe import *
 from meutils.schemas.oneapi import BASE_URL
@@ -37,7 +38,7 @@ headers = {
 #         if response.is_success:
 #             data = response.json()
 #             return data
-@rcache(ttl=7 * 24 * 3600)
+# @rcache(ttl=7 * 24 * 3600)
 async def get_api_key_log(api_key: str) -> Optional[list]:  # 日志查询会超时：为了获取 user_id, todo缓存 永久缓存 sk => user
     try:
         async with httpx.AsyncClient(base_url=BASE_URL) as client:
@@ -132,10 +133,13 @@ if __name__ == '__main__':
     # arun(put_user(payload['data'], -1))
     # arun(get_api_key_log("sk-"))
 
-    # arun(get_api_key_log('sk-iPNbgHSRkQ9VUb6iACa7a4539D74255A6462d29619d6519'))
-    arun(get_user_money("sk-"))
+    # arun(get_api_key_log(os.getenv("OPENAI_API_KEY")))
+
+    # arun(get_user_money("sk-"))
     # arun(get_user_from_api_key('sk-idDBqyoDVqCXInnO9uaGLUfwsxY7RhzHSn166z5jOBCBvFmY'))
 
     # arun(get_user_for_quota("sk-"))
 
+    arun(get_user(11327))
+
     # arun(update_user_for_refund(2, quota=73065879))
