@@ -12,14 +12,13 @@ import time
 from meutils.pipe import *
 from meutils.io.files_utils import to_url
 from meutils.decorators.retry import retrying
+
 from meutils.llm.clients import AsyncClient
 from meutils.schemas.openai_types import CompletionRequest
 from meutils.schemas.video_types import VideoRequest
 
-from meutils.notice.feishu import send_message_for_volc as send_message
-
 from meutils.db.redis_db import redis_aclient
-from meutils.llm.check_utils import check_token_for_volc as check
+from meutils.llm.check_utils import check_token_for_volc
 from meutils.config_utils.lark_utils import get_next_token_for_polling, get_series
 
 from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks
@@ -28,31 +27,40 @@ from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request,
 FEISHU_URL = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=8W6kk8"  # 超刷
 
 
-async def get_valid_token(tokens: Optional[list] = None, force_update: bool = True, batch_size: int = 1):
+async def get_valid_token(tokens: Optional[list] = None, batch_size: Optional[int] = None, seed: int = 0,
+                          recheck: bool = False):
+    """返回 tokens
+    api_key = np.random.choice(api_key.split())
+
+    """
     tokens = tokens or await get_series(FEISHU_URL, duplicated=True)
+    batch_size = batch_size or 1
 
-    if token := await redis_aclient.get("volc-token"):  # list
-        token = token.decode()
+#     tokens = """
+#     90f18a26-e4f1-4bea-b692-93d2883b3bcc
+# 95b3f0ef-a93b-4e10-829a-d2274f448201""".split()
+#     await redis_aclient.set("volc_tokens", "\n".join(tokens))
 
-        if force_update:  # 强制检测更新
-            if await check(token):
-                return token
-            else:
-                await redis_aclient.delete("volc-token")  # 删除无效
-        else:
-            return token
-    for i, token in enumerate(tokens, 1):
-        if await check(token):
-            await redis_aclient.set("volc-token", token, ex=2 * 3600 - 10 * 60)
+    if seed == 0 and (volc_tokens := await redis_aclient.get(f"volc_tokens")):  # 刷新
+        volc_tokens = volc_tokens.decode()
+        if recheck:
+            valid_tokens = await check_token_for_volc(volc_tokens.split('\n'))
+            volc_tokens = '\n'.join(valid_tokens)
 
-            return token
-        if batch_size == i:
-            break
+        return volc_tokens
 
-    logger.debug(f"无效 {token}")
-    _ = f"{time.ctime()}\n\n{FEISHU_URL}\n\n所有token无效\n\n{token}"
-    logger.error(_)
-    send_message(_, n=3)
+    valid_tokens = []
+    for token in tokens:
+        if token := await check_token_for_volc([token]):
+            valid_tokens += token
+
+            logger.debug(valid_tokens)
+            if len(valid_tokens) == batch_size:
+                _ = '\n'.join(valid_tokens)
+                await redis_aclient.set(f"volc_tokens", _, ex=2 * 3600)
+                # ttl =await redis_aclient.ttl(f"volc_tokens")
+
+                return _
 
 
 # check_image_and_video = partial(check, purpose='video and image')
@@ -61,7 +69,9 @@ async def get_valid_token(tokens: Optional[list] = None, force_update: bool = Tr
 @retrying()
 async def create_task(request: Union[CompletionRequest, VideoRequest], api_key: Optional[str] = None):
     # api_key = api_key or await get_next_token_for_polling(feishu_url=FEISHU_URL, check_token=check)
-    api_key = api_key or await get_valid_token(force_update=False)
+    api_key = api_key or await get_valid_token()
+
+    api_key = np.random.choice(api_key.split('\n'))
 
     # feishu_url = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=rcoDg7"
     # api_key = api_key or await get_next_token_for_polling(
@@ -267,7 +277,10 @@ c4356b58-4aa3-4a52-b907-b40c4dd2e502
     # arun(get_task_from_feishu(ids, tokens))
     # arun(get_task_from_feishu(ids, ))
 
+    # arun(get_valid_token(['a93ea9a5-3831-47b8-863a-57e10233f922']))
+    # arun(get_valid_token(batch_size=2))
     arun(get_valid_token())
+    # arun(get_valid_token(recheck=True))
 
 """
 {'id': 'cgt-20250613160030-2dvd7',
