@@ -21,6 +21,7 @@ from meutils.oss.minio_oss import Minio
 from starlette.datastructures import UploadFile
 from contextlib import asynccontextmanager
 from httpx import AsyncClient
+from PIL import Image
 
 
 def guess_mime_type(file):
@@ -71,7 +72,7 @@ async def to_bytes(
         if file.startswith('http'):
             logger.debug(f"FileType: HTTP")
 
-            async with AsyncClient(headers=headers or {}, timeout=300) as cilent:  # todo: 缓存 根据大小
+            async with AsyncClient(headers=headers or {}, timeout=120) as cilent:  # todo: 缓存 根据大小 判断有效链接
                 resp = await cilent.get(file)
                 file_bytes = resp.content
 
@@ -154,7 +155,7 @@ async def to_url(
         content_type: Optional[str] = None,
         mime_type: Optional[str] = None,
 
-):
+):  # 传入 url 是否 转存
     if not file: return
 
     content_type = content_type or mime_type
@@ -260,6 +261,29 @@ async def get_file_duration(filename: str = ".mp4", url: Optional[str] = None, c
         return int(np.ceil(tag.duration or 10))
 
 
+async def to_png(image: Union[bytes, List[bytes], str, List[str]], response_format: str = 'bytes'):
+    """
+    将 WebP 二进制数据无损转换为 PNG 二进制数据
+    """
+    if isinstance(image, list):
+        tasks = [to_png(_, response_format) for _ in image]
+        return await asyncio.gather(*tasks)
+
+    if isinstance(image, str):
+        image = await to_bytes(image)
+        if not image:
+            raise Exception(f"invalid image: {image}")
+
+    with Image.open(io.BytesIO(image)) as im:
+        out = io.BytesIO()
+        im.save(out, format="PNG")  # 无损
+
+        if response_format != "bytes":
+            return await to_base64(out.getvalue(), content_type="image/png")
+
+        return out.getvalue()
+
+
 if __name__ == '__main__':
     # import tempfile
     #
@@ -342,12 +366,24 @@ if __name__ == '__main__':
     #     arun(get_file_duration(url=url))
 
     # r = arun(to_url([]))
-    text = "这是一个示例文本，包含一个图片：![image](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABAAAAAQACAIAAADwf7zUAAAgAElEQ) 这张图片很棒。"
+    # text = "这是一个示例文本，包含一个图片：![image](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABAAAAAQACAIAAADwf7zUAAAgAElEQ) 这张图片很棒。"
+    #
+    # arun(markdown_base64_to_url(
+    #     text=text,
+    #     # pattern=r'!\[.*?\]\((data:image/.*?)\)'
+    #     # pattern=r'!\[.*?\]\((.*?)\)'
+    #
+    # )
+    # )
 
-    arun(markdown_base64_to_url(
-        text=text,
-        # pattern=r'!\[.*?\]\((data:image/.*?)\)'
-        # pattern=r'!\[.*?\]\((.*?)\)'
+    # webp_bytes = Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/apis/images/image1.webp").read_bytes()
+    # webp_bytes = Path("image_0.emf",).read_bytes()
+    #
+    # arun(to_png(webp_bytes, response_format='b64'))
 
-    )
-    )
+
+    url = "https://r2.syntx.ai/user_5317909153/uploaded/5a8b8eaabe4d56957053cb5dee790abf_photo_2025-09-17_17-03-07_1758152505.jpg"
+    url = "https://mjimg.zhanjuzhe.cn/raw/banana_media/202509/17/20250917110929784771.JPG".lower()
+    arun(to_png(url, response_format='b64'))
+
+    # guess_mime_type('xx.jpg')
