@@ -36,6 +36,8 @@ def calculate_min_resolution(w, h):
 
 
 def size2aspect_ratio(size):
+    if not size: return "1:1"
+
     if 'x' in size:
         w, h = size.split('x')
         w, h = calculate_min_resolution(w, h)
@@ -49,3 +51,4 @@ if __name__ == '__main__':
     print(size2aspect_ratio("1920x1080"))
     print(size2aspect_ratio("1920:1080"))
     print(size2aspect_ratio("1024x1024"))
+    print(size2aspect_ratio("16:9"))
