@@ -84,22 +84,34 @@ class ImagesResponse(_ImagesResponse):
 class ImageRequest(BaseModel):  # openai
     """
     图生图 两种方式： prompt + controls
+
+        background: Optional[Literal["transparent", "opaque", "auto"]] | NotGiven = NOT_GIVEN,
+        model: Union[str, ImageModel, None] | NotGiven = NOT_GIVEN,
+        output_compression: Optional[int] | NotGiven = NOT_GIVEN,
+        output_format: Optional[Literal["png", "jpeg", "webp"]] | NotGiven = NOT_GIVEN,
+        partial_images: Optional[int] | NotGiven = NOT_GIVEN,
+
     """
     model: str = ''
 
     prompt: constr(min_length=1, max_length=10240) = " "
 
-    n: Optional[int] = 1
+    moderation: Optional[Literal["low", "auto"]] = None
 
-    quality: Optional[Literal["standard", "hd"]] = None
-    style: Union[str, Literal["vivid", "natural"]] = None
+    style: Optional[Union[str, Literal["vivid", "natural"]]] = None
+    background: Optional[Union[str, Literal["transparent", "opaque", "auto"]]] = None
+    input_fidelity: Optional[Union[str, Literal["high", "low"]]] = None
+    quality: Optional[Union[str, Literal["standard", "low", "medium", "high", "auto"]]] = None
 
     # 测试默认值 Optional[Literal["256x256", "512x512", "1024x1024", "1792x1024", "1024x1792"]]
+    n: Optional[int] = 1
     size: Optional[str] = '1024x1024'  # null auto
 
+    output_format: Optional[Literal["png", "jpeg", "webp"]] = None
     response_format: Optional[Literal["url", "b64_json", "oss_url", "glb", "stl"]] = "url"
 
     seed: Optional[int] = None
+    stream: Optional[bool] = None
 
     # oneapi https://github.com/QuantumNous/new-api/blob/main/dto/dalle.go
     extra_fields: Optional[Any] = None  ###
@@ -114,24 +126,33 @@ class ImageRequest(BaseModel):  # openai
 
     aspect_ratio: Optional[str] = None
 
-    user: Optional[str] = None  # to_url_fal
+    user: Optional[str] = None
 
-    image: Optional[Union[str, List[str]]] = None  # url b64
+    image: Optional[Union[str, List[str], bytes, List[bytes]]] = None  # url b64 file_bytes
     watermark: Optional[bool] = None
 
     def __init__(self, /, **data: Any):
         super().__init__(**data)
+        # 规避空字符
+        self.style = self.style or None
+        self.quality = self.quality or None
+        self.background = self.background or None
+        self.input_fidelity = self.input_fidelity or None
 
-        if self.aspect_ratio:  # 适配比例
-            self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
+        if not self.model.startswith(("doubao-seed",)):
 
-        elif self.size == 'auto':
-            self.size = self.aspect_ratio = None
+            if self.aspect_ratio:  # 适配比例
+                self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
 
-        elif self.size:  # 适配尺寸
-            self.aspect_ratio = size2aspect_ratio(self.size)
+            elif self.size == 'auto':
+                self.size = self.aspect_ratio = None
 
-            self.size = self.size if 'x' in self.size else '512x512'
+            elif self.size:  # 适配尺寸
+                # if self.size.lower().endswith('k'):
+                #     size = int(self.size.lower().split('k')[0]) * 1024
+                #     self.size = f"{size}x{size}"
+                self.aspect_ratio = size2aspect_ratio(self.size)
+                self.size = self.size if 'x' in self.size else '512x512'
 
     @cached_property
     def image_urls(self) -> List[str]:
@@ -187,37 +208,58 @@ class ImageRequest(BaseModel):  # openai
 class ImageEditRequest(BaseModel):
     model: Union[str, Literal["dall-e-2", "dall-e-3", "gpt-image-1"]]
 
+    # image: Union[FileTypes, SequenceNotStr[FileTypes]],
+    # prompt: str,
+    # mask: FileTypes | NotGiven = NOT_GIVEN,
+
     prompt: str
     image: Any  # 图片
 
     mask: Optional[Any] = None  # 图片
-    background: Optional[Literal["transparent", "opaque", "auto"]] = None
+
+    background: Optional[Union[str, Literal["transparent", "opaque", "auto"]]] = None
+    input_fidelity: Optional[Union[str, Literal["high", "low"]]] = None
+    quality: Optional[Union[str, Literal["standard", "low", "medium", "high", "auto"]]] = None
 
     n: Optional[int] = 1
-    quality: Optional[Literal["standard", "low", "medium", "high", "auto"]] = None
     size: Optional[
         Union[str, Literal["256x256", "512x512", "1024x1024", "1536x1024", "1024x1536", "auto"]]] = "1024x1024"
-    response_format: Optional[Literal["url", "b64_json"]] = None
 
     aspect_ratio: Optional[str] = None
 
     user: Optional[str] = None
+    stream: Optional[bool] = None
+
+    response_format: Optional[Literal["url", "b64_json"]] = None
+    output_format: Optional[Literal["png", "jpeg", "webp"]] = None
+
+    # output_compression: Optional[int] | NotGiven = NOT_GIVEN,
+    # partial_images: Optional[int] | NotGiven = NOT_GIVEN,
 
     def __init__(self, /, **data: Any):
         super().__init__(**data)
+        # 规避空字符
+        self.quality = self.quality or None
+        self.background = self.background or None
+        self.input_fidelity = self.input_fidelity or None
+
         if not isinstance(self.image, list):
             self.image = [self.image]
 
-        if self.aspect_ratio:  # 适配比例
-            self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
+        if not self.model.startswith(("doubao-seed",)):
 
-        elif self.size == 'auto':
-            self.size = self.aspect_ratio = None
+            if self.aspect_ratio:  # 适配比例
+                self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
 
-        elif self.size:  # 适配尺寸
-            self.aspect_ratio = size2aspect_ratio(self.size)
+            elif self.size == 'auto':
+                self.size = self.aspect_ratio = None
 
-            self.size = self.size if 'x' in self.size else '512x512'
+            elif self.size:  # 适配尺寸
+                # if self.size.lower().endswith('k'):
+                #     size = int(self.size.lower().split('k')[0]) * 1024
+                #     self.size = f"{size}x{size}"
+                self.aspect_ratio = size2aspect_ratio(self.size)
+                self.size = self.size if 'x' in self.size else '512x512'
 
 
 class FalImageRequest(ImageRequest):
@@ -619,9 +661,19 @@ if __name__ == '__main__':
         prompt=prompt,
 
         # size="16x9",
+        # size="1K",
+        size="2K",
 
-        aspect_ratio="16:9"
+        # size="auto",
+
+        # aspect_ratio="16:9"
     )
+
+    # "sequential_image_generation": "auto",
+    # "sequential_image_generation_options": {
+    #     "max_images": 4
+    # },
+
     #
     # print(request.prompt)
     #
@@ -649,3 +701,7 @@ if __name__ == '__main__':
     # r = ImageRequest(**data)
 
     # print(ImagesResponse())
+
+    # print(request)
+
+    print(dict(Image()))
\ No newline at end of file
