@@ -29,6 +29,7 @@ FAL_MODELS = {
     "fal-ai/clarity-upscaler": 1,  # Your request will cost $0.03 per upscaled megapixel.
 
     'fal-kling-video-lipsync-audio-to-video': 0.5,
+    'fal-ai/kling-video/lipsync/text-to-video': 0.14 * FAL,
 
     'fal-pixverse-v4.5-effects': 1,
     'fal-pixverse-v4.5-text-to-video': 0.9,
@@ -58,7 +59,7 @@ FAL_MODELS = {
     "fal-ai/minimax/hailuo-02/pro/text-to-video": 0.48 * FAL,
     "fal-ai/minimax/hailuo-02/pro/image-to-video": 0.48 * FAL,
 
-    "fal-ai/minimax/voice-clone": 5,
+    "fal-ai/minimax/voice-clone": 3,
 
     # vidu
     "fal-ai/vidu/q1/text-to-video": 0.4 * FAL_,
@@ -185,6 +186,7 @@ MODEL_PRICE = {
     "jimeng-video-3.0": 0.5,
     "doubao-seedream-3-0-t2i-250415": 0.1,
     "doubao-seededit-3-0-i2i-250628": 0.1,
+    "doubao-seedream-4-0-250828": 0.1,
 
     "doubao-seedance-1-0-pro": 0.5,  # 480 1080
     "doubao-seedance-1-0-pro-250528": 0.5,  # 480 1080
@@ -619,6 +621,9 @@ MODEL_RATIO = {
     "doubao-embedding-large-text-250515": 0.25,
     "doubao-embedding-text-240715": 0.35,
 
+    "seed-oss-36b-instruct": 0.75,
+    "ling-mini-2.0": 0.25,
+
     # 百川
     'baichuan4-turbo': 7.5,
     'baichuan4-air': 0.49,
@@ -641,6 +646,8 @@ MODEL_RATIO = {
     "grok-3-mini-beta": 0.15,
     "grok-3-mini-fast-beta": 0.3,
 
+    "grok-code-fast-1": 0.1,
+
     "grok-4": 1.5,
 
     # 定制
@@ -663,12 +670,15 @@ MODEL_RATIO = {
     "kimi": 5,
     "kimi-128k": 5,
     "kimi-dev-72b": 1,
-    "moonshotai/kimi-k2-instruct": 2,
-    "kimi-k2-0711-preview": 2,
     "kimi-k2-turbo-preview": 2,
+
     "kimi-k2-250711": 2,
+    "kimi-k2-0711-preview": 2,
+    "kimi-k2-instruct-0711": 2,
+
     "kimi-k2-250905": 2,
     "kimi-k2-0905-preview": 2,
+    "kimi-k2-instruct-0905": 2,
 
     # 智谱 https://www.bigmodel.cn/pricing
     'glm-4-9b-chat': 0.1,
@@ -715,6 +725,10 @@ MODEL_RATIO = {
     "qwen-max-2025-01-25": 1.2 * 1,
     "qwen3-max": 3,
     "qwen3-max-preview": 3,
+    "qwen3-next-80b-a3b": 0.5,
+    "qwen3-next-80b-a3b-instruct": 0.5,
+    "qwen3-next-80b-a3b-thinking": 0.5,
+    "tongyi-deepresearch-30b-a3b": 0.5,
 
     "qwen-vl-max-latest": 1.5,
     "qwen-vl-plus-latest": 0.75,
@@ -743,8 +757,8 @@ MODEL_RATIO = {
     "qwen3-235b-a22b": 1,
     "qwen-math-plus": 2,
     "qwen3-coder-480b-a35b-instruct": 3,
-    "qwen3-235b-a22b-instruct-2507": 2,
-    "qwen3-235b-a22b-thinking-2507": 2,
+    "qwen3-235b-a22b-instruct-2507": 1,
+    "qwen3-235b-a22b-thinking-2507": 1,
 
     "qwen3-coder-plus": 2,
     "qwen3-coder-plus-2025-07-22": 2,
@@ -1258,12 +1272,15 @@ COMPLETION_RATIO = {
     "kimi-latest-128k": 3,
     "kimi-dev-72b": 4,
     "kimi-vl-a3b-thinking": 5,
-    "moonshotai/kimi-k2-instruct": 4,
-    "kimi-k2-0711-preview": 4,
     "kimi-k2-turbo-preview": 4,
+
     "kimi-k2-250711": 4,
+    "kimi-k2-0711-preview": 4,
+    "kimi-k2-instruct-0711": 4,
+
     "kimi-k2-250905": 4,
     "kimi-k2-0905-preview": 4,
+    "kimi-k2-instruct-0905": 4,
 
     "moonshot-v1-8k": 5,
     "moonshot-v1-32k": 4,
@@ -1288,6 +1305,8 @@ COMPLETION_RATIO = {
     "grok-3-mini-fast-beta": 4 / 0.6,
     "grok-4": 5,
 
+    "grok-code-fast-1": 7.5,
+
     "gpt-4.5-preview-2025-02-27": 2,
 
     "o1-mini": 4,
@@ -1433,7 +1452,7 @@ COMPLETION_RATIO = {
     "gemini-2.5-pro-think": 8,
 
     "gemini-2.5-pro-thinking": 8,
-    "gemini-2.5-pro-exp-03-25-thinking":8,
+    "gemini-2.5-pro-exp-03-25-thinking": 8,
     "gemini-2.5-pro-preview-03-25-thinking": 8,
     "gemini-2.5-pro-nothinking": 8,
 
@@ -1448,7 +1467,6 @@ COMPLETION_RATIO = {
     "gemini-2.5-flash-preview-05-20": 8.4,
     "gemini-2.5-flash-preview-05-20-nothinking": 8.4,
 
-
     "hunyuan-a52b-instruct": 5,
     "qwen2.5-coder-32b-instruct": 3,
 
@@ -1462,6 +1480,10 @@ COMPLETION_RATIO = {
     "qwen-max": 4,
     "qwen3-max": 4,
     "qwen3-max-preview": 4,
+    "qwen3-next-80b-a3b": 4,
+    "qwen3-next-80b-a3b-instruct": 4,
+    "qwen3-next-80b-a3b-thinking": 10,
+    "tongyi-deepresearch-30b-a3b": 4,
 
     "qwen-vl-max-latest": 3,
     "qwen-vl-plus-latest": 3,
@@ -1505,6 +1527,7 @@ COMPLETION_RATIO = {
     "qwen3-32b": 4,
     "qwen3-30b-a3b": 4,
     "qwen3-30b-a3b-instruct-2507": 4,
+
     "qwen3-235b-a22b": 4,
     "qwenlong-l1-32b": 4,
     "qwen3-235b-a22b-instruct-2507": 4,
@@ -1569,6 +1592,9 @@ COMPLETION_RATIO = {
 
     "doubao-1-5-thinking-vision-pro-250428": 3,
 
+    "seed-oss-36b-instruct": 4,
+    "ling-mini-2.0": 4,
+
     "deepseek-prover-v2-671b": 4,
     "deepseek-r1:1.5b": 4,
     "deepseek-r1-distill-qwen-1.5b": 4,
@@ -1660,7 +1686,7 @@ COMPLETION_RATIO = {
     "meta-llama/Llama-3.2-11B-Vision-Instruct": 4,
 
     "mistral-small-3.1-24b-instruct": 0.1,
-    "mistral-small-24b-instruct-2501": 3
+    "mistral-small-24b-instruct-2501": 3,
 
 }
 
